@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-05-28T14:18:18.679359Z $
-# $Revision: 1508 $
+# $Date: 2007-05-29T05:19:01.144060Z $
+# $Revision: 1515 $
 # $Author: unobe $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,7 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.0.9');
+use version; our $VERSION = qv('0.1.1');
 
 use Moose;
 extends 'Moose::Object';
@@ -45,11 +45,12 @@ sub _login_form {
 sub login {
     my ( $self, $token ) = @_;
     my $agent = $self->base->mech->agent_alias( 'Mac Mozilla' );
-    $self->base->mech->get(
-        $self->login_uri
-        . '?api_key=' . $self->base->api_key
-        . '&v=1.0'
-        . "&auth_token=$token"
+    $self->base->mech->post(
+        $self->login_uri,
+        { 'api_key'     => $self->base->api_key,
+          'v'           => '1.0',
+          'auth_token'  => $token,
+        }
     );
     if ( not $self->base->mech->forms ) {
         confess 'No form to submit!';
@@ -72,7 +73,7 @@ WWW::Facebook::API::Login - Ask for user login info
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Login version 0.0.9
+This document describes WWW::Facebook::API::Login version 0.1.1
 
 
 =head1 SYNOPSIS
